@@ -2,16 +2,17 @@ use strict;
 use warnings;
 package MetaCPAN::API;
 # ABSTRACT: A comprehensive, DWIM-featured API to MetaCPAN (DEPRECATED)
-$MetaCPAN::API::VERSION = '0.50';
+
+our $VERSION = '0.51';
+
 use Moo;
 use Types::Standard qw<Str ArrayRef InstanceOf>;
 use namespace::autoclean;
 
 use Carp;
-use JSON;
+use JSON::MaybeXS 1.001000;
 use Try::Tiny;
-use HTTP::Tiny;
-use URI::Escape 'uri_escape';
+use HTTP::Tiny 0.014;
 
 with qw/
     MetaCPAN::API::Author
@@ -29,7 +30,7 @@ with qw/
 has base_url => (
     is      => 'ro',
     isa     => Str,
-    default => sub{'http://api.metacpan.org/v0'},
+    default => sub{'https://fastapi.metacpan.org/v1'},
 );
 
 has ua => (
@@ -48,6 +49,8 @@ has ua_args => (
     },
 );
 
+my $JSON = JSON::MaybeXS->new(canonical => 1, utf8 => 1);
+
 sub _build_ua {
     my $self = shift;
     return HTTP::Tiny->new( @{ $self->ua_args } );
@@ -76,7 +79,7 @@ sub post {
     ref $query and ref $query eq 'HASH'
         or croak 'Second argument of query hashref must be provided';
 
-    my $query_json = to_json( $query, { canonical => 1 } );
+    my $query_json = $JSON->encode( $query );
     my $result     = $self->ua->request(
         'POST',
         "$base/$url",
@@ -112,7 +115,7 @@ sub _decode_result {
     defined ( my $content = $result->{'content'} )
         or croak 'Missing content in return value';
 
-    try   { $decoded_result = decode_json $content }
+    try   { $decoded_result = $JSON->decode( $content ) }
     catch { croak "Couldn't decode '$content': $_" };
 
     return $decoded_result;
@@ -127,13 +130,11 @@ sub _build_extra_params {
 
     # if it's deep, JSON encoding needs to be involved
     if (scalar grep { ref } values %extra) {
-        my $query_json = to_json( \%extra, { canonical => 1 } );
+        my $query_json = $JSON->encode( \%extra );
         %extra = ( source => $query_json );
     }
 
-    my $extra = join '&', map {
-        "$_=" . uri_escape( $extra{$_} )
-    } sort keys %extra;
+    my $extra = $self->ua->www_form_urlencode(\%extra);
 
     return $extra;
 }
@@ -152,7 +153,7 @@ MetaCPAN::API - A comprehensive, DWIM-featured API to MetaCPAN (DEPRECATED)
 
 =head1 VERSION
 
-version 0.50
+version 0.51
 
 =head1 SYNOPSIS
 
@@ -206,7 +207,7 @@ MetaCPAN is accessible. By default it's already set correctly, but if you're
 running a local instance of MetaCPAN, or use a local mirror, or tunnel it
 through a local port, or any of those stuff, you would want to change this.
 
-Default: I<http://api.metacpan.org/v0>.
+Default: I<https://fastapi.metacpan.org/v1>.
 
 This attribute is read-only (immutable), meaning that once it's set on
 initialize (via C<new()>), you cannot change it. If you need to, create a
